@@ -2,7 +2,7 @@ context("Test search_fields")
 
 test_that("search_fields returns correct types of field", {
   expect_setequal(unique(search_fields(type = "all")$type),
-               c("fields", "assertions", "layers"))
+               c("fields", "assertions", "layers", "media"))
   expect_equal(unique(search_fields(type = "assertions")$type),
                "assertions")
   expect_error(search_fields(type = "layer"))
